@@ -9,6 +9,7 @@ Exchange and Queue declarations.
 
 """
 from kombu.abstract import MaybeChannelBound
+from kombu.syn import blocking as _SYN
 
 TRANSIENT_DELIVERY_MODE = 1
 PERSISTENT_DELIVERY_MODE = 2
@@ -142,12 +143,12 @@ class Exchange(MaybeChannelBound):
             response will not be waited for. Default is :const:`False`.
 
         """
-        return self.channel.exchange_declare(exchange=self.name,
-                                             type=self.type,
-                                             durable=self.durable,
-                                             auto_delete=self.auto_delete,
-                                             arguments=self.arguments,
-                                             nowait=nowait)
+        return _SYN(self.channel.exchange_declare, exchange=self.name,
+                                                type=self.type,
+                                                durable=self.durable,
+                                                auto_delete=self.auto_delete,
+                                                arguments=self.arguments,
+                                                nowait=nowait)
 
     def Message(self, body, delivery_mode=None, priority=None,
             content_type=None, content_encoding=None, properties=None,
@@ -214,9 +215,9 @@ class Exchange(MaybeChannelBound):
             response will not be waited for. Default is :const:`False`.
 
         """
-        return self.channel.exchange_delete(exchange=self.name,
-                                            if_unused=if_unused,
-                                            nowait=nowait)
+        return _SYN(self.channel.exchange_delete, exchange=self.name,
+                                                  if_unused=if_unused,
+                                                  nowait=nowait)
 
     def __eq__(self, other):
         if isinstance(other, Exchange):
@@ -368,13 +369,13 @@ class Queue(MaybeChannelBound):
             without modifying the server state.
 
         """
-        return self.channel.queue_declare(queue=self.name,
-                                          passive=passive,
-                                          durable=self.durable,
-                                          exclusive=self.exclusive,
-                                          auto_delete=self.auto_delete,
-                                          arguments=self.queue_arguments,
-                                          nowait=nowait)
+        return _SYN(self.channel.queue_declare, queue=self.name,
+                                                passive=passive,
+                                                durable=self.durable,
+                                                exclusive=self.exclusive,
+                                                auto_delete=self.auto_delete,
+                                                arguments=self.queue_arguments,
+                                                nowait=nowait)
 
     def queue_bind(self, nowait=False):
         """Create the queue binding on the server.
@@ -382,11 +383,11 @@ class Queue(MaybeChannelBound):
         :keyword nowait: Do not wait for a reply.
 
         """
-        return self.channel.queue_bind(queue=self.name,
-                                       exchange=self.exchange.name,
-                                       routing_key=self.routing_key,
-                                       arguments=self.binding_arguments,
-                                       nowait=nowait)
+        return _SYN(self.channel.queue_bind, queue=self.name,
+                                             exchange=self.exchange.name,
+                                             routing_key=self.routing_key,
+                                             arguments=self.binding_arguments,
+                                             nowait=nowait)
 
     def get(self, no_ack=None):
         """Poll the server for a new message.
@@ -403,13 +404,14 @@ class Queue(MaybeChannelBound):
         is more important than performance.
 
         """
-        message = self.channel.basic_get(queue=self.name, no_ack=no_ack)
+        message = _SYN(self.channel.basic_get, queue=self.name, no_ack=no_ack)
         if message is not None:
             return self.channel.message_to_python(message)
 
     def purge(self, nowait=False):
         """Remove all messages from the queue."""
-        return self.channel.queue_purge(queue=self.name, nowait=nowait) or 0
+        return _SYN(self.channel.queue_purge, queue=self.name,
+                                              nowait=nowait) or 0
 
     def consume(self, consumer_tag=None, callback=None, no_ack=None,
             nowait=False):
@@ -454,17 +456,17 @@ class Queue(MaybeChannelBound):
         :keyword nowait: Do not wait for a reply.
 
         """
-        return self.channel.queue_delete(queue=self.name,
-                                         if_unused=if_unused,
-                                         if_empty=if_empty,
-                                         nowait=nowait)
+        return _SYN(self.channel.queue_delete, queue=self.name,
+                                               if_unused=if_unused,
+                                               if_empty=if_empty,
+                                               nowait=nowait)
 
     def unbind(self):
         """Delete the binding on the server."""
-        return self.channel.queue_unbind(queue=self.name,
-                                         exchange=self.exchange.name,
-                                         routing_key=self.routing_key,
-                                         arguments=self.binding_arguments)
+        return _SYN(self.channel.queue_unbind, queue=self.name,
+                                            exchange=self.exchange.name,
+                                            routing_key=self.routing_key,
+                                            arguments=self.binding_arguments)
 
     def __eq__(self, other):
         if isinstance(other, Queue):
