@@ -13,9 +13,10 @@ Emulates the AMQ API for non-AMQ transports.
 import socket
 
 from itertools import count
-from time import sleep
+from time import sleep, time
 from Queue import Empty
 
+from kombu.exceptions import StdChannelError
 from kombu.transport import base
 from kombu.utils import emergency_dump_state, say
 from kombu.utils.compat import OrderedDict
@@ -207,6 +208,15 @@ class AbstractChannel(object):
         """
         pass
 
+    def _has_queue(self, queue, **kwargs):
+        """Verify that queue exists.
+
+        Should return :const:`True` if the queue exists or :const:`False`
+        otherwise.
+
+        """
+        return True
+
     def _poll(self, cycle, timeout=None):
         """Poll a list of queues for available messages."""
         return cycle.get()
@@ -239,6 +249,7 @@ class Channel(AbstractChannel):
         self._consumers = set()
         self._cycle = None
         self._tag_to_queue = {}
+        self._active_queues = []
         self._qos = None
         self.closed = False
 
@@ -274,9 +285,15 @@ class Channel(AbstractChannel):
             self.queue_delete(queue, if_unused=True, if_empty=True)
         self.state.exchanges.pop(exchange, None)
 
-    def queue_declare(self, queue, **kwargs):
+    def queue_declare(self, queue, passive=False, **kwargs):
         """Declare queue."""
-        self._new_queue(queue, **kwargs)
+        if passive and not self._has_queue(queue, **kwargs):
+            raise StdChannelError("404",
+                    u"NOT_FOUND - no queue %r in vhost %r" % (
+                        queue, self.connection.client.virtual_host or '/'),
+                    (50, 10), "Channel.queue_declare")
+        else:
+            self._new_queue(queue, **kwargs)
         return queue, self._size(queue), 0
 
     def queue_delete(self, queue, if_unusued=False, if_empty=False, **kwargs):
@@ -311,12 +328,16 @@ class Channel(AbstractChannel):
         message["properties"]["delivery_info"]["exchange"] = exchange
         message["properties"]["delivery_info"]["routing_key"] = routing_key
         message["properties"]["delivery_tag"] = self._next_delivery_tag()
-        for queue in self._lookup(exchange, routing_key):
-            self._put(queue, message, **kwargs)
+        if self.typeof(exchange).type == "fanout" and self.supports_fanout:
+            self._put_fanout(exchange, message, **kwargs)
+        else:
+            for queue in self._lookup(exchange, routing_key):
+                self._put(queue, message, **kwargs)
 
     def basic_consume(self, queue, no_ack, callback, consumer_tag, **kwargs):
         """Consume from `queue`"""
         self._tag_to_queue[consumer_tag] = queue
+        self._active_queues.append(queue)
 
         def _callback(raw_message):
             message = self.Message(self, raw_message)
@@ -326,6 +347,7 @@ class Channel(AbstractChannel):
 
         self.connection._callbacks[queue] = _callback
         self._consumers.add(consumer_tag)
+
         self._reset_cycle()
 
     def basic_cancel(self, consumer_tag):
@@ -333,6 +355,10 @@ class Channel(AbstractChannel):
         self._consumers.remove(consumer_tag)
         self._reset_cycle()
         queue = self._tag_to_queue.pop(consumer_tag, None)
+        try:
+            self._active_queues.remove(queue)
+        except ValueError:
+            pass
         self.connection._callbacks.pop(queue, None)
 
     def basic_get(self, queue, **kwargs):
@@ -437,10 +463,13 @@ class Channel(AbstractChannel):
         """Close channel, cancel all consumers, and requeue unacked
         messages."""
         self.closed = True
-        map(self.basic_cancel, list(self._consumers))
+        for consumer in list(self._consumers):
+            self.basic_cancel(consumer)
         self.qos.restore_unacked_once()
         self.connection.close_channel(self)
-        self._cycle = None
+        if self._cycle is not None:
+            self._cycle.close()
+            self._cycle = None
 
     def _reset_cycle(self):
         self._cycle = FairCycle(self._get, self._active_queues, Empty)
@@ -463,10 +492,6 @@ class Channel(AbstractChannel):
             self._qos = QoS(self)
         return self._qos
 
-    @property
-    def _active_queues(self):
-        return [self._tag_to_queue[tag] for tag in self._consumers]
-
     @property
     def cycle(self):
         if self._cycle is None:
@@ -488,7 +513,7 @@ class Transport(base.Transport):
 
     #: :class:`BrokerState` containing declared exchanges and
     #: bindings (set by constructor).
-    state = None
+    state = BrokerState()
 
     #: :class:`~kombu.transport.virtual.scheduling.FairCycle` instance
     #: used to fairly drain events from channels (set by constructor).
@@ -511,8 +536,6 @@ class Transport(base.Transport):
         self.channels = []
         self._callbacks = {}
         self.cycle = self.Cycle(self._drain_channel, self.channels, Empty)
-        if self.state is None:
-            self.state = BrokerState()
 
     def create_channel(self, connection):
         channel = self.Channel(connection)
@@ -529,6 +552,7 @@ class Transport(base.Transport):
         return self     # for drain events
 
     def close_connection(self, connection):
+        self.cycle.close()
         while self.channels:
             try:
                 channel = self.channels.pop()
@@ -538,14 +562,13 @@ class Transport(base.Transport):
                 channel.close()
 
     def drain_events(self, connection, timeout=None):
-        if not self.channels:
-            raise ValueError("No channels to drain events from.")
         loop = 0
+        time_start = time()
         while 1:
             try:
-                item, channel = self.cycle.get()
+                item, channel = self.cycle.get(timeout=timeout)
             except Empty:
-                if timeout and loop * 0.1 >= timeout:
+                if timeout and time() - time_start >= timeout:
                     raise socket.timeout()
                 loop += 1
                 sleep(0.1)
@@ -561,5 +584,5 @@ class Transport(base.Transport):
 
         self._callbacks[queue](message)
 
-    def _drain_channel(self, channel):
-        return channel.drain_events()
+    def _drain_channel(self, channel, timeout=None):
+        return channel.drain_events(timeout=timeout)
