@@ -29,13 +29,21 @@ class FairCycle(object):
                 return resource
             except IndexError:
                 self.pos = 0
+                if not self.resources:
+                    raise self.predicate()
 
-    def get(self):
+    def get(self, **kwargs):
         for tried in count(0):
             resource = self._next()
 
             try:
-                return self.fun(resource), resource
+                return self.fun(resource, **kwargs), resource
             except self.predicate:
                 if tried >= len(self.resources) - 1:
                     raise
+
+    def close(self):
+        pass
+
+    def __repr__(self):
+        return "<FairCycle: %r>" % (self.resources, )
